@@ -134,7 +134,7 @@ split_date (GogAxis *axis, double val, GDate *date)
 		return TRUE;
 	}
 
-	datetime_serial_to_g (date, (int)val, axis->date_conv);
+	go_date_serial_to_g (date, (int)val, axis->date_conv);
 	return !g_date_valid (date);
 }
 
@@ -535,14 +535,14 @@ map_date_auto_bound (GogAxis *axis, double minimum, double maximum, double *boun
 		minor_step = 1;
 	} else if (years < 2) {
 		g_date_set_day (&min_date, 1);
-		minimum = datetime_g_to_serial (&min_date, axis->date_conv);
+		minimum = go_date_g_to_serial (&min_date, axis->date_conv);
 
 		if (g_date_get_year (&max_date) < 9999 ||
 		    g_date_get_month (&max_date) < 12) {
 			g_date_set_day (&max_date, 1);
 			g_date_add_months (&max_date, 1);
 		}
-		maximum = datetime_g_to_serial (&max_date, axis->date_conv);
+		maximum = go_date_g_to_serial (&max_date, axis->date_conv);
 
 		step = 30;
 		minor_step = (range <= 180 ? 1 : step);
@@ -570,8 +570,8 @@ map_date_auto_bound (GogAxis *axis, double minimum, double maximum, double *boun
 		if (g_date_valid_dmy (1, 1, y))
 			g_date_set_dmy (&max_date, 1, 1, y);
 
-		minimum = datetime_g_to_serial (&min_date, axis->date_conv);
-		maximum = datetime_g_to_serial (&max_date, axis->date_conv);
+		minimum = go_date_g_to_serial (&min_date, axis->date_conv);
+		maximum = go_date_g_to_serial (&max_date, axis->date_conv);
 		range = maximum - minimum;
 		step = DAYS_IN_YEAR * N;
 		minor_step = step / (N == 1 ? 12 : 10);
@@ -630,10 +630,10 @@ map_linear_auto_bound (GogAxis *axis, double minimum, double maximum, double *bo
 
 	/* pull to zero if its nearby (do not pull both directions to 0) */
 	if (bound[GOG_AXIS_ELEM_MIN] > 0 &&
-	    (bound[GOG_AXIS_ELEM_MIN] - 10. * step) < 0)
+	    (bound[GOG_AXIS_ELEM_MIN] - 9.99 * step) < 0)
 		bound[GOG_AXIS_ELEM_MIN] = 0;
 	else if (bound[GOG_AXIS_ELEM_MAX] < 0 &&
-	    (bound[GOG_AXIS_ELEM_MAX] + 10. * step) > 0)
+	    (bound[GOG_AXIS_ELEM_MAX] + 9.99 * step) > 0)
 		bound[GOG_AXIS_ELEM_MAX] = 0;
 
 	/* The epsilon shift can pull us away from a zero we want to
@@ -842,7 +842,7 @@ map_date_calc_ticks (GogAxis *axis)
 
 		if (!add_months (&maj_d, maj_i * (int)maj_months))
 			break;
-		maj_pos = datetime_g_to_serial (&maj_d, axis->date_conv);
+		maj_pos = go_date_g_to_serial (&maj_d, axis->date_conv);
 		if (maj_pos > maximum)
 			break;
 
@@ -872,7 +872,7 @@ map_date_calc_ticks (GogAxis *axis)
 				if (!add_months (&min_d, min_i * (int)min_months))
 					break;
 			}
-			min_pos = datetime_g_to_serial (&min_d, axis->date_conv);
+			min_pos = go_date_g_to_serial (&min_d, axis->date_conv);
 			if (min_pos > maximum)
 				break;
 
@@ -1103,7 +1103,7 @@ map_log_auto_bound (GogAxis *axis, double minimum, double maximum, double *bound
 	bound[GOG_AXIS_ELEM_MIN] = pow (10.0, minimum);
 	bound[GOG_AXIS_ELEM_MAX] = pow (10.0, maximum);
 	bound[GOG_AXIS_ELEM_MAJOR_TICK] = step;
-	bound[GOG_AXIS_ELEM_MINOR_TICK] = 8;
+	bound[GOG_AXIS_ELEM_MINOR_TICK] = 9 * step - 1;
 }
 
 static void
@@ -1116,6 +1116,7 @@ map_log_calc_ticks (GogAxis *axis)
 	int t, N;
 	int maj_i, maj_N; /* Ticks for -1,....,maj_N     */
 	int min_i, min_N; /* Ticks for 1,....,(min_N-1) */
+	int base10_unit = 0;
 
 	if (!gog_axis_get_bounds (axis, &minimum, &maximum) ||
 	    minimum <= 0.0) {
@@ -1151,17 +1152,38 @@ map_log_calc_ticks (GogAxis *axis)
 	if (min_step < 0) {
 		min_N = 1;
 	} else if (base10) {
-		double mf = pow (10, maj_step);
-		if (min_step >= mf - 2 && maj_N * (mf - 1) <= GOG_AXIS_MAX_TICK_NBR)
-			min_N = (int)mf - 1;
-		else
-			min_N = 1;
+		int ims = (int)maj_step;
+		/*
+		 * We basically have three choices:
+		 *   9N-1 : minor ticks at {1,2,...,9}*10^n and at 10^n
+		 *          without major ticks.
+		 *   N-1  : minor ticks at 10^n without major tick
+		 *
+		 *   1    : no minor ticks.
+		 */
+		do {
+			if (min_step >= 9 * ims - 1)
+				min_step = 9 * ims - 1;
+			else if (min_step >= ims - 1)
+				min_step = ims - 1;
+			else
+				min_step = 0;
+
+			if (maj_N * (min_step + 1) > GOG_AXIS_MAX_TICK_NBR) {
+				min_step -= 1;
+				continue;
+			}
+		} while (0);
+
+		min_N = (int)min_step + 1;
+		base10_unit = (min_N == ims ? 1 : 9);
+		min_step = go_nan;
 	} else {
 		while ((min_step + 1) * maj_N > GOG_AXIS_MAX_TICK_NBR)
 			min_step = floor (min_step / 2);
 		min_N = 1 + (int)min_step;
+		min_step = maj_step / min_N;
 	}
-	min_step = maj_step / min_N;
 
 	start_i = go_fake_ceil (lminimum / maj_step);
 	maj_N = (int)(go_fake_floor (lmaximum / maj_step) - start_i);
@@ -1197,7 +1219,9 @@ map_log_calc_ticks (GogAxis *axis)
 			double min_pos;
 
 			if (base10) {
-				min_pos = maj_pos * (1 + min_i);
+				min_pos = maj_pos *
+					go_pow10 (min_i / base10_unit) *
+					(1 + min_i % base10_unit);
 			} else {
 				double min_lpos = maj_lpos + min_i * min_step;
 				min_pos = pow (10, min_lpos);
@@ -2046,7 +2070,6 @@ gog_axis_update (GogObject *obj)
 #ifdef GOFFICE_WITH_GTK
 
 typedef struct {
-	GladeXML 	*gui;
 	GogAxis		*axis;
 	GtkWidget 	*format_selector;
 } GogAxisPrefState;
@@ -2056,8 +2079,6 @@ gog_axis_pref_state_free (GogAxisPrefState *state)
 {
 	if (state->axis != NULL)
 		g_object_unref (state->axis);
-	if (state->gui != NULL)
-		g_object_unref (state->gui);
 	g_free (state);
 }
 
@@ -2244,19 +2265,18 @@ gog_axis_populate_editor (GogObject *gobj,
 	GogAxis *axis = GOG_AXIS (gobj);
 	GogAxisPrefState *state;
 	GogDataset *set = GOG_DATASET (gobj);
-	GladeXML *gui;
+	GtkBuilder *gui;
 
-	gui = go_glade_new ("gog-axis-prefs.glade", "axis_pref_box", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new ("gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
 	state = g_new0 (GogAxisPrefState, 1);
-	state->gui = gui;
 	state->axis = axis;
 	g_object_ref (G_OBJECT (axis));
 
 	/* Bounds Page */
-	table = GTK_TABLE (glade_xml_get_widget (gui, "bound_table"));
+	table = GTK_TABLE (gtk_builder_get_object (gui, "bound_table"));
 	if (axis->is_discrete) {
 		static char const * const dim_names[] = {
 			N_("M_inimum"),
@@ -2283,38 +2303,39 @@ gog_axis_populate_editor (GogObject *gobj,
 
 	/* Details page */
 	if (!axis->is_discrete && gog_axis_get_atype (axis) != GOG_AXIS_CIRCULAR) {
-		GtkWidget *w = glade_xml_get_widget (gui, "map_type_combo");
-		gog_axis_map_populate_combo (axis, GTK_COMBO_BOX (w));
-		g_signal_connect_object (G_OBJECT (w),
+		GtkComboBox *box = go_gtk_builder_combo_box_init_text (gui, "map_type_combo");
+		gog_axis_map_populate_combo (axis, box);
+		g_signal_connect_object (G_OBJECT (box),
 					 "changed",
 					 G_CALLBACK (cb_map_combo_changed),
 					 axis, 0);
 	} else {
-		GtkWidget *w = glade_xml_get_widget (gui, "map_type_box");
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "map_type_box");
 		gtk_widget_hide (w);
 	}
 
 	if (!axis->is_discrete && gog_axis_get_atype (axis) == GOG_AXIS_CIRCULAR) {
-		GtkWidget *w = glade_xml_get_widget (gui, "polar_unit_combo");
-		gog_axis_populate_polar_unit_combo (axis, GTK_COMBO_BOX (w));
-		g_signal_connect (G_OBJECT (w),
+		GtkWidget *w;
+		GtkComboBox *box = go_gtk_builder_combo_box_init_text (gui, "polar_unit_combo");
+		gog_axis_populate_polar_unit_combo (axis, box);
+		g_signal_connect (G_OBJECT (box),
 				  "changed",
 				  G_CALLBACK (cb_polar_unit_changed),
 				  state);
 
-		w = glade_xml_get_widget (gui, "circular_rotation_spinbutton");
+		w = go_gtk_builder_get_widget (gui, "circular_rotation_spinbutton");
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis->circular_rotation);
 		g_signal_connect_object (G_OBJECT (w), "value-changed",
 					 G_CALLBACK (cb_rotation_changed),
 					 axis, 0);
 	} else {
-		GtkWidget *w = glade_xml_get_widget (gui, "circular_table");
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "circular_table");
 		gtk_widget_hide (w);
 	}
 
 	for (i = 0; i < G_N_ELEMENTS (toggle_props) ; i++) {
 		gboolean cur_val;
-		GtkWidget *w = glade_xml_get_widget (gui, toggle_props[i]);
+		GtkWidget *w = go_gtk_builder_get_widget (gui, toggle_props[i]);
 
 		g_object_get (G_OBJECT (gobj), toggle_props[i], &cur_val, NULL);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), cur_val);
@@ -2324,7 +2345,7 @@ gog_axis_populate_editor (GogObject *gobj,
 	}
 
 	go_editor_add_page (editor,
-			     glade_xml_get_widget (gui, "axis_pref_box"),
+			     go_gtk_builder_get_widget (gui, "axis_pref_box"),
 			     _("Scale"));
 
 	if (gog_object_is_visible (axis) && gog_axis_get_atype (axis) < GOG_AXIS_VIRTUAL) {
@@ -2343,14 +2364,14 @@ gog_axis_populate_editor (GogObject *gobj,
 
 		    go_editor_add_page (editor, w, _("Format"));
 
-		    gtk_widget_show (w);
 		    g_signal_connect (G_OBJECT (w),
 			    "format_changed", G_CALLBACK (cb_axis_fmt_changed), axis);
 	    }
 	}
-	w = glade_xml_get_widget (gui, "axis_pref_box");
-	g_object_set_data_full (G_OBJECT (w), "state", state,
-				(GDestroyNotify)gog_axis_pref_state_free);
+
+	g_object_set_data_full (gtk_builder_get_object (gui, "axis_pref_box"),
+				"state", state, (GDestroyNotify) gog_axis_pref_state_free);  
+	g_object_unref (gui);
 
 	go_editor_set_store_page (editor, &axis_pref_page);
 }
@@ -2365,7 +2386,8 @@ gog_axis_init_style (GogStyledObject *gso, GOStyle *style)
 	else
 		style->interesting_fields = 0;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-				style, GOG_OBJECT (gso), 0, FALSE);
+				style, GOG_OBJECT (gso), 0, GO_STYLE_LINE |
+	                        GO_STYLE_FONT | GO_STYLE_TEXT_LAYOUT);
 }
 
 static void
