@@ -25,9 +25,10 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/utils/go-color.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-marker.h>
 #include <goffice/utils/go-path.h>
@@ -160,22 +161,23 @@ gog_legend_update (GogObject *obj)
 
 static void
 gog_legend_populate_editor (GogObject *gobj, 
-			    GogEditor *editor, 
+			    GOEditor *editor, 
 			    GogDataAllocator *dalloc, 
 			    GOCmdContext *cc)
 {
 	static guint legend_pref_page = 0;
 
 	(GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
-	gog_editor_set_store_page (editor, &legend_pref_page);
+	go_editor_set_store_page (editor, &legend_pref_page);
 }
 
 static void
-gog_legend_init_style (GogStyledObject *gso, GogStyle *style)
+gog_legend_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL | GO_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), 0, FALSE);
+		style, GOG_OBJECT (gso), 0, GO_STYLE_OUTLINE | GO_STYLE_FILL |
+	        GO_STYLE_FONT);
 }
 
 static void
@@ -227,7 +229,7 @@ gog_legend_init (GogLegend *legend)
 
 GSF_CLASS (GogLegend, gog_legend,
 	   gog_legend_class_init, gog_legend_init,
-	   GOG_OUTLINED_OBJECT_TYPE)
+	   GOG_TYPE_OUTLINED_OBJECT)
 
 #define	GLV_ELEMENT_HEIGHT_EM		1.2	/* Legend element height, in font size */
 #define GLV_LINE_WIDTH_MAX_DEFAULT_EM	0.5	/* Maximum sample line width, in font size */
@@ -254,14 +256,14 @@ typedef struct {
 
 typedef GogOutlinedViewClass	GogLegendViewClass;
 
-#define GOG_LEGEND_VIEW_TYPE	(gog_legend_view_get_type ())
-#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LEGEND_VIEW_TYPE, GogLegendView))
-#define IS_GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LEGEND_VIEW_TYPE))
+#define GOG_TYPE_LEGEND_VIEW	(gog_legend_view_get_type ())
+#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LEGEND_VIEW, GogLegendView))
+#define GOG_IS_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LEGEND_VIEW))
 
 static GogViewClass *lview_parent_klass;
 
 static void
-cb_size_elements (unsigned i, GogStyle const *style, 
+cb_size_elements (unsigned i, GOStyle const *style, 
 		  char const *name, GogLegendView *glv)
 {
 	GogView *view = GOG_VIEW (glv);
@@ -273,7 +275,7 @@ cb_size_elements (unsigned i, GogStyle const *style,
 		glv->element_width = aabr.w;
 	if (glv->element_height < aabr.h)
 		glv->element_height = aabr.h;
-	if (!glv->uses_lines && (style->interesting_fields & GOG_STYLE_LINE)) 
+	if (!glv->uses_lines && (style->interesting_fields & GO_STYLE_LINE)) 
 		glv->uses_lines = TRUE;
 }
 
@@ -286,7 +288,7 @@ gog_legend_view_size_request (GogView *v,
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
 	GogViewRequisition child_req, residual, frame_req;
-	GogStyle *style;
+	GOStyle *style;
 	double available_space, element_size;
 	unsigned num_elements;
 
@@ -316,7 +318,7 @@ gog_legend_view_size_request (GogView *v,
 		return;
 	}
 
-	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
+	style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
 	gog_renderer_push_style (v->renderer, style);
 	
 	glv->font_size = pango_font_description_get_size (style->font.font->desc) / PANGO_SCALE;
@@ -372,10 +374,10 @@ typedef struct {
 } SwatchScaleClosure;
 
 static void
-cb_swatch_scale (unsigned i, GogStyle const *style, char const *name,
+cb_swatch_scale (unsigned i, GOStyle const *style, char const *name,
 		 SwatchScaleClosure *data)
 {
-	GogStyleLine const *line = NULL;
+	GOStyleLine const *line = NULL;
 	double size;
 	double maximum, scale;
 
@@ -385,10 +387,8 @@ cb_swatch_scale (unsigned i, GogStyle const *style, char const *name,
 	if (data->size_min > size)
 		data->size_min = size;
 
-	if (style->interesting_fields & GOG_STYLE_LINE)
+	if (style->interesting_fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE))
 		line = &style->line;
-	else if (style->interesting_fields & GOG_STYLE_OUTLINE)
-		line = &style->outline;
 
 	if (line == NULL ||
 	    line->width <= data->hairline_width)
@@ -424,13 +424,13 @@ typedef struct {
 } RenderClosure;
 
 static void
-cb_render_elements (unsigned index, GogStyle const *base_style, char const *name,
+cb_render_elements (unsigned index, GOStyle const *base_style, char const *name,
 		    RenderClosure *data)
 {
 	GogView const *view = data->view;
 	GogLegendView *glv = GOG_LEGEND_VIEW (view);
 	GogRenderer *renderer = view->renderer;
-	GogStyle *style = NULL;
+	GOStyle *style = NULL;
 	GogViewAllocation pos, rectangle;
 	double half_width, y;
 	GOPath *line_path;
@@ -446,8 +446,8 @@ cb_render_elements (unsigned index, GogStyle const *base_style, char const *name
 	}
 	data->count++;
 
-	if (base_style->interesting_fields & GOG_STYLE_LINE) { /* line and marker */
-		style = gog_style_dup (base_style);
+	if (base_style->interesting_fields & GO_STYLE_LINE) { /* line and marker */
+		style = go_style_dup (base_style);
 		g_return_if_fail (style != NULL);
 		go_marker_set_size (style->marker.mark,
 				    go_marker_get_size (style->marker.mark) *
@@ -461,7 +461,7 @@ cb_render_elements (unsigned index, GogStyle const *base_style, char const *name
 		y = data->y + glv->element_height / 2.;
 		go_path_move_to (line_path, data->x + half_width, y);
 		go_path_line_to (line_path, data->x + data->swatch.w * GLV_LINE_LENGTH_EM - half_width, y);
-		if (style->interesting_fields & GOG_STYLE_FILL) {
+		if (style->interesting_fields & GO_STYLE_FILL) {
 			rectangle.x = data->x - half_width;
 			rectangle.y = y;
 			rectangle.w = data->swatch.w * GLV_LINE_LENGTH_EM + 2.0 * half_width;
@@ -472,10 +472,10 @@ cb_render_elements (unsigned index, GogStyle const *base_style, char const *name
 		go_path_free (line_path);
 		gog_renderer_draw_marker (renderer, data->x + data->swatch.w  * GLV_LINE_LENGTH_EM * 0.5, y);
 	} else {					/* area swatch */
-		style = gog_style_dup (base_style);
-		if (style->outline.width > data->hairline_width)
-			style->outline.width =
-				0.5 * (data->hairline_width + style->outline.width) * data->line_scale_a +
+		style = go_style_dup (base_style);
+		if (style->line.width > data->hairline_width)
+			style->line.width =
+				0.5 * (data->hairline_width + style->line.width) * data->line_scale_a +
 				data->line_scale_b;
 
 		rectangle = data->swatch;
@@ -501,7 +501,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 {
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
-	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
 	RenderClosure data;
 	SwatchScaleClosure swatch_data;
 	double swatch_size_min;
@@ -592,4 +592,4 @@ gog_legend_view_class_init (GogLegendViewClass *gview_klass)
 
 static GSF_CLASS (GogLegendView, gog_legend_view,
 		  gog_legend_view_class_init, NULL,
-		  GOG_OUTLINED_VIEW_TYPE)
+		  GOG_TYPE_OUTLINED_VIEW)
