@@ -19,10 +19,10 @@
  * USA
  */
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-graph-impl.h>
 #include <goffice/graph/gog-view.h>
+#include <goffice/graph/gog-renderer.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-units.h>
 #include <goffice/utils/go-cairo.h>
@@ -75,14 +75,13 @@ struct _GogRenderer {
 	GClosure *font_watcher;
 	gboolean  needs_update;
 
-	GogStyle const *cur_style;
+	GOStyle const *cur_style;
 	GSList   *style_stack;
 
 	GOLineDashSequence 	*line_dash;
-	GOLineDashSequence 	*outline_dash;
 
-	GogStyle 	*grip_style;
-	GogStyle 	*selection_style;
+	GOStyle 	*grip_style;
+	GOStyle 	*selection_style;
 
 	int 		 w, h;
 
@@ -105,8 +104,8 @@ typedef struct {
 	void (*request_update) (GogRenderer *renderer);
 } GogRendererClass;
 
-#define GOG_RENDERER_CLASS(k)	 (G_TYPE_CHECK_CLASS_CAST ((k), GOG_RENDERER_TYPE, GogRendererClass))
-#define IS_GOG_RENDERER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GOG_RENDERER_TYPE))
+#define GOG_RENDERER_CLASS(k)	 (G_TYPE_CHECK_CLASS_CAST ((k), GOG_TYPE_RENDERER, GogRendererClass))
+#define GOG_IS_RENDERER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GOG_TYPE_RENDERER))
 
 #define GRC_LINEAR_SCALE(w,scale) (go_sub_epsilon (w) <= 0.0 ? GOG_RENDERER_HAIRLINE_WIDTH_PTS : w) * scale
 
@@ -144,16 +143,12 @@ _update_dash (GogRenderer *rend)
 
 	go_line_dash_sequence_free (rend->line_dash);
 	rend->line_dash = NULL;
-	go_line_dash_sequence_free (rend->outline_dash);
-	rend->outline_dash = NULL;
 
 	if (rend->cur_style == NULL)
 		return;
 
 	size = _line_size (rend, rend->cur_style->line.width, FALSE);
 	rend->line_dash = go_line_dash_get_sequence (rend->cur_style->line.dash_type, size);
-	size = _line_size (rend, rend->cur_style->outline.width, FALSE);
-	rend->outline_dash = go_line_dash_get_sequence (rend->cur_style->outline.dash_type, size);
 }
 
 double
@@ -185,11 +180,11 @@ gog_renderer_pt2r (GogRenderer const *rend, double d)
 static void
 emit_line (GogRenderer *rend, gboolean preserve, GOPathOptions options)
 {
-	GogStyle const *style = rend->cur_style;
+	GOStyle const *style = rend->cur_style;
 	cairo_t *cr = rend->cairo;
 	double width;
 
-	if (!gog_style_is_line_visible (style)) {
+	if (!go_style_is_line_visible (style)) {
 		if (!preserve)
 			cairo_new_path (cr);
 		return;
@@ -215,47 +210,14 @@ emit_line (GogRenderer *rend, gboolean preserve, GOPathOptions options)
 		cairo_stroke (cr);
 }
 
-static void
-emit_outline (GogRenderer *rend, gboolean preserve, GOPathOptions options)
-{
-	GogStyle const *style = rend->cur_style;
-	cairo_t *cr = rend->cairo;
-	double width;
-
-	if (!gog_style_is_outline_visible (style)) {
-		if (!preserve)
-			cairo_new_path (cr);
-		return;
-	}
-
-	width = _grc_line_size (rend, style->outline.width, options & GO_PATH_OPTIONS_SNAP_WIDTH);
-	cairo_set_line_width (cr, width);
-	if (rend->outline_dash != NULL)
-		cairo_set_dash (cr,
-				rend->outline_dash->dash,
-				rend->outline_dash->n_dash,
-				rend->outline_dash->offset);
-	else
-		cairo_set_dash (cr, NULL, 0, 0);
-
-	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (style->outline.color));
-	cairo_set_line_cap (cr, (width <= 2.0 && !rend->is_vector) ?
-			    CAIRO_LINE_CAP_SQUARE : CAIRO_LINE_CAP_ROUND);
-
-	if (preserve)
-		cairo_stroke_preserve (cr);
-	else
-		cairo_stroke (cr);
-}
-
 static void
 emit_fill (GogRenderer *rend, gboolean preserve)
 {
-	GogStyle const *style = rend->cur_style;
+	GOStyle const *style = rend->cur_style;
 	cairo_t *cr = rend->cairo;
 	cairo_pattern_t *cr_pattern = NULL;
 
-	cr_pattern = gog_style_create_cairo_pattern (style, cr);
+	cr_pattern = go_style_create_cairo_pattern (style, cr);
 	if (cr_pattern == NULL) {
 		if (!preserve)
 			cairo_new_path (cr);
@@ -433,28 +395,23 @@ void
 gog_renderer_stroke_serie (GogRenderer *renderer,
 			   GOPath const *path)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 	GOPathOptions line_options;
-	gboolean is_outline;
 	double width;
 
-	g_return_if_fail (IS_GOG_RENDERER (renderer));
+	g_return_if_fail (GOG_IS_RENDERER (renderer));
 	g_return_if_fail (renderer->cur_style != NULL);
-	g_return_if_fail (IS_GO_PATH (path));
+	g_return_if_fail (GO_IS_PATH (path));
 
         style = renderer->cur_style;
-	is_outline = style->interesting_fields & GOG_STYLE_OUTLINE;
 	line_options = go_path_get_options (path);
 	width = _grc_line_size (renderer,
-				is_outline ?  style->outline.width : style->line.width,
+				style->line.width,
 				line_options & GO_PATH_OPTIONS_SNAP_WIDTH);
 
-	if (gog_style_is_line_visible (style)) {
+	if (go_style_is_line_visible (style)) {
 		path_interpret (renderer, path, width);
-		if (is_outline)
-			emit_outline (renderer, FALSE, go_path_get_options (path));
-		else
-			emit_line (renderer, FALSE, go_path_get_options (path));
+		emit_line (renderer, FALSE, go_path_get_options (path));
 	}
 }
 
@@ -463,15 +420,15 @@ gog_renderer_fill_serie (GogRenderer *renderer,
 			 GOPath const *path,
 			 GOPath const *close_path)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 
-	g_return_if_fail (IS_GOG_RENDERER (renderer));
+	g_return_if_fail (GOG_IS_RENDERER (renderer));
 	g_return_if_fail (renderer->cur_style != NULL);
-	g_return_if_fail (IS_GO_PATH (path));
+	g_return_if_fail (GO_IS_PATH (path));
 
 	style = renderer->cur_style;
 
-	if (gog_style_is_fill_visible (style)) {
+	if (go_style_is_fill_visible (style)) {
 		fill_path_interpret (renderer, path, close_path);
 		emit_fill (renderer, FALSE);
 	}
@@ -480,20 +437,18 @@ gog_renderer_fill_serie (GogRenderer *renderer,
 static void
 _draw_shape (GogRenderer *renderer, GOPath const *path, gboolean fill, gboolean stroke)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 	GOPathOptions line_options;
 	double width;
-	gboolean use_outline;
 
-	g_return_if_fail (IS_GOG_RENDERER (renderer));
+	g_return_if_fail (GOG_IS_RENDERER (renderer));
 	g_return_if_fail (renderer->cur_style != NULL);
-	g_return_if_fail (IS_GO_PATH (path));
+	g_return_if_fail (GO_IS_PATH (path));
 
         style = renderer->cur_style;
-	use_outline = style->interesting_fields & GOG_STYLE_OUTLINE;
 
 	line_options = go_path_get_options (path);
-	width = stroke ? _grc_line_size (renderer, use_outline ? style->outline.width : style->line.width,
+	width = stroke ? _grc_line_size (renderer, style->line.width,
 					 line_options & GO_PATH_OPTIONS_SNAP_WIDTH) : 0;
 
 	path_interpret (renderer, path, width);
@@ -501,12 +456,8 @@ _draw_shape (GogRenderer *renderer, GOPath const *path, gboolean fill, gboolean
 	if (fill)
 		emit_fill (renderer, stroke);
 
-	if (stroke) {
-		if (use_outline)
-			emit_outline (renderer, FALSE, go_path_get_options (path));
-		else
-			emit_line (renderer, FALSE, go_path_get_options (path));
-	}
+	if (stroke)
+		emit_line (renderer, FALSE, go_path_get_options (path));
 }
 
 void
@@ -541,8 +492,8 @@ gog_renderer_fill_shape (GogRenderer *renderer, GOPath const *path)
 void
 gog_renderer_push_clip (GogRenderer *rend, GOPath const *path)
 {
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (IS_GO_PATH (path));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
+	g_return_if_fail (GO_IS_PATH (path));
 
 	cairo_save (rend->cairo);
 
@@ -592,7 +543,7 @@ gog_renderer_push_clip_rectangle (GogRenderer *rend, double x, double y, double
 void
 gog_renderer_pop_clip (GogRenderer *rend)
 {
-	g_return_if_fail (IS_GOG_RENDERER (rend));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
 
 	cairo_restore (rend->cairo);
 }
@@ -600,22 +551,22 @@ gog_renderer_pop_clip (GogRenderer *rend)
 static void
 _draw_circle (GogRenderer *rend, double x, double y, double r, gboolean fill, gboolean stroke)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 	GOPath *path;
 	gboolean narrow = r < 1.5;
 	double o, o_2;
 
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (IS_GOG_STYLE (rend->cur_style));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
+	g_return_if_fail (GO_IS_STYLE (rend->cur_style));
 
 	style = rend->cur_style;
-	narrow |= !gog_style_is_outline_visible (style);
+	narrow |= !go_style_is_outline_visible (style);
 
 	path = go_path_new ();
 	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
 
 	if (!narrow) {
-		o = gog_renderer_line_size (rend, style->outline.width);
+		o = gog_renderer_line_size (rend, style->line.width);
 		o_2 = o / 2.;
 	} else
 		o = o_2 = 0.;
@@ -657,22 +608,22 @@ gog_renderer_fill_circle (GogRenderer *rend, double x, double y, double r)
 static void
 _draw_rectangle (GogRenderer *rend, GogViewAllocation const *rect, gboolean fill, gboolean stroke)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 	GOPath *path;
 	gboolean narrow = (rect->w < 3.) || (rect->h < 3.);
 	double o, o_2;
 
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (IS_GOG_STYLE (rend->cur_style));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
+	g_return_if_fail (GO_IS_STYLE (rend->cur_style));
 
 	style = rend->cur_style;
-	narrow |= !gog_style_is_outline_visible (style);
+	narrow |= !go_style_is_outline_visible (style);
 
 	path = go_path_new ();
 	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
 
 	if (!narrow) {
-		o = gog_renderer_line_size (rend, style->outline.width);
+		o = gog_renderer_line_size (rend, style->line.width);
 		o_2 = o / 2.;
 	} else
 		o = o_2 = 0.;
@@ -717,16 +668,16 @@ gog_renderer_draw_grip (GogRenderer *renderer, double x, double y)
 	GogViewAllocation rectangle;
 
 	if (renderer->grip_style == NULL) {
-		GogStyle *style;
+		GOStyle *style;
 
-		style = gog_style_new ();
-		style->outline.dash_type = GO_LINE_SOLID;
-		style->outline.width = 0.0;
-		style->outline.color =
+		style = go_style_new ();
+		style->line.dash_type = GO_LINE_SOLID;
+		style->line.width = 0.0;
+		style->line.color =
 		style->fill.pattern.back = 0xff000080;
 		style->fill.pattern.pattern = GO_PATTERN_SOLID;
-		style->fill.type = GOG_FILL_STYLE_PATTERN;
-		style->interesting_fields = GOG_STYLE_FILL | GOG_STYLE_OUTLINE;
+		style->fill.type = GO_STYLE_FILL_PATTERN;
+		style->interesting_fields = GO_STYLE_FILL | GO_STYLE_OUTLINE;
 
 		renderer->grip_style = style;
 	}
@@ -746,14 +697,14 @@ void
 gog_renderer_draw_selection_rectangle (GogRenderer *renderer, GogViewAllocation const *rectangle)
 {
 	if (renderer->selection_style == NULL) {
-		GogStyle *style;
+		GOStyle *style;
 
-		style = gog_style_new ();
-		style->outline.dash_type = GO_LINE_DOT;
-		style->outline.width = 0.0;
-		style->outline.color = 0x0000ffB0;
-		style->fill.type = GOG_FILL_STYLE_NONE;
-		style->interesting_fields = GOG_STYLE_OUTLINE;
+		style = go_style_new ();
+		style->line.dash_type = GO_LINE_DOT;
+		style->line.width = 0.0;
+		style->line.color = 0x0000ffB0;
+		style->fill.type = GO_STYLE_FILL_NONE;
+		style->interesting_fields = GO_STYLE_OUTLINE;
 
 		renderer->selection_style = style;
 	}
@@ -791,7 +742,7 @@ gog_renderer_draw_marker (GogRenderer *rend, double x, double y)
 {
 	cairo_surface_t *surface;
 
-	g_return_if_fail (IS_GOG_RENDERER (rend));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
 	g_return_if_fail (rend->cur_style != NULL);
 
 	if (rend->is_vector && !rend->marker_as_surface) {
@@ -839,10 +790,10 @@ gog_renderer_draw_text (GogRenderer *rend, char const *text,
 	cairo_t *cairo = rend->cairo;
 	GOGeometryOBR obr;
 	GOGeometryAABR aabr;
-	GogStyle const *style;
+	GOStyle const *style;
 	int iw, ih;
 
-	g_return_if_fail (IS_GOG_RENDERER (rend));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
 	g_return_if_fail (rend->cur_style != NULL);
 	g_return_if_fail (text != NULL);
 
@@ -910,13 +861,13 @@ void
 gog_renderer_get_text_OBR (GogRenderer *rend, char const *text,
 			   gboolean use_markup, GOGeometryOBR *obr)
 {
-	GogStyle const *style;
+	GOStyle const *style;
 	PangoLayout *layout;
 	PangoContext *context;
 	PangoRectangle logical;
 	cairo_t *cairo = rend->cairo;
 
-	g_return_if_fail (IS_GOG_RENDERER (rend));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
 	g_return_if_fail (rend->cur_style != NULL);
 	g_return_if_fail (text != NULL);
 	g_return_if_fail (obr != NULL);
@@ -981,10 +932,10 @@ _free_marker_data (GogRenderer *rend)
 }
 
 void
-gog_renderer_push_style (GogRenderer *rend, GogStyle const *style)
+gog_renderer_push_style (GogRenderer *rend, GOStyle const *style)
 {
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (IS_GOG_STYLE (style));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
+	g_return_if_fail (GO_IS_STYLE (style));
 
 	if (rend->cur_style != NULL)
 		rend->style_stack = g_slist_prepend (
@@ -1000,8 +951,8 @@ gog_renderer_push_style (GogRenderer *rend, GogStyle const *style)
 void
 gog_renderer_pop_style (GogRenderer *rend)
 {
-	g_return_if_fail (IS_GOG_RENDERER (rend));
-	g_return_if_fail (IS_GOG_STYLE (rend->cur_style));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
+	g_return_if_fail (GO_IS_STYLE (rend->cur_style));
 
 	g_object_unref ((gpointer)rend->cur_style);
 	if (rend->style_stack != NULL) {
@@ -1019,7 +970,7 @@ gog_renderer_pop_style (GogRenderer *rend)
 void
 gog_renderer_request_update (GogRenderer *renderer)
 {
-	g_return_if_fail (IS_GOG_RENDERER (renderer));
+	g_return_if_fail (GOG_IS_RENDERER (renderer));
 
 	if (renderer->needs_update)
 		return;
@@ -1049,8 +1000,8 @@ gog_renderer_update (GogRenderer *rend, double w, double h)
 
 	if (w <= 0 || h <= 0)
 		return FALSE;
-	g_return_val_if_fail (IS_GOG_RENDERER (rend), FALSE);
-	g_return_val_if_fail (IS_GOG_VIEW (rend->view), FALSE);
+	g_return_val_if_fail (GOG_IS_RENDERER (rend), FALSE);
+	g_return_val_if_fail (GOG_IS_VIEW (rend->view), FALSE);
 
 	size_changed = rend->w != w || rend->h != h;
 	if (size_changed) {
@@ -1134,7 +1085,7 @@ gog_renderer_update (GogRenderer *rend, double w, double h)
 GdkPixbuf *
 gog_renderer_get_pixbuf (GogRenderer *rend)
 {
-	g_return_val_if_fail (IS_GOG_RENDERER (rend), NULL);
+	g_return_val_if_fail (GOG_IS_RENDERER (rend), NULL);
 
 	if (rend->cairo_surface == NULL)
 		return NULL;
@@ -1158,7 +1109,7 @@ gog_renderer_get_pixbuf (GogRenderer *rend)
 cairo_surface_t *
 gog_renderer_get_cairo_surface (GogRenderer *rend)
 {
-	g_return_val_if_fail (IS_GOG_RENDERER (rend), NULL);
+	g_return_val_if_fail (GOG_IS_RENDERER (rend), NULL);
 
 	return rend->cairo_surface;
 }
@@ -1199,9 +1150,9 @@ gog_renderer_render_to_cairo (GogRenderer *renderer, cairo_t *cairo, double widt
 	GogViewAllocation allocation;
 	double width_in_pts, height_in_pts;
 
-	g_return_val_if_fail (IS_GOG_RENDERER (renderer), FALSE);
-	g_return_val_if_fail (IS_GOG_VIEW (renderer->view), FALSE);
-	g_return_val_if_fail (IS_GOG_GRAPH (renderer->model), FALSE);
+	g_return_val_if_fail (GOG_IS_RENDERER (renderer), FALSE);
+	g_return_val_if_fail (GOG_IS_VIEW (renderer->view), FALSE);
+	g_return_val_if_fail (GOG_IS_GRAPH (renderer->model), FALSE);
 
 	gog_graph_force_update (renderer->model);
 	gog_graph_get_size (renderer->model, &width_in_pts, &height_in_pts);
@@ -1259,7 +1210,7 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 	double width_in_pts, height_in_pts;
 	gboolean result;
 
-	g_return_val_if_fail (IS_GOG_RENDERER (rend), FALSE);
+	g_return_val_if_fail (GOG_IS_RENDERER (rend), FALSE);
 
 	if (x_dpi <= 0.)
 		x_dpi = 96.;
@@ -1384,7 +1335,7 @@ do_export_vectorial:
 double
 gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
 {
-	g_return_val_if_fail (IS_GOG_RENDERER (rend), GOG_RENDERER_HAIRLINE_WIDTH_PTS);
+	g_return_val_if_fail (GOG_IS_RENDERER (rend), GOG_RENDERER_HAIRLINE_WIDTH_PTS);
 
 	if (rend->is_vector
 	    || go_sub_epsilon (rend->scale) <= 0.0)
@@ -1392,15 +1343,16 @@ gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
 
 	return 1.0 / rend->scale;
 }
-#ifdef GOFFICE_WITH_GMATHML
+
+#ifdef GOFFICE_WITH_LASEM
 
 void
-gog_renderer_draw_equation (GogRenderer *renderer, GMathmlView *mathml_view, double x, double y)
+gog_renderer_draw_equation (GogRenderer *renderer, LsmMathmlView *mathml_view, double x, double y)
 {
 	cairo_t *cairo;
 
-	g_return_if_fail (IS_GOG_RENDERER (renderer));
-	g_return_if_fail (GMATHML_IS_VIEW (mathml_view));
+	g_return_if_fail (GOG_IS_RENDERER (renderer));
+	g_return_if_fail (LSM_IS_MATHML_VIEW (mathml_view));
 
 	cairo = renderer->cairo;
 
@@ -1408,8 +1360,8 @@ gog_renderer_draw_equation (GogRenderer *renderer, GMathmlView *mathml_view, dou
 
 	cairo_scale (cairo, renderer->scale_x, renderer->scale_y);
 
-	gmathml_view_set_cairo (mathml_view, cairo);
-	gmathml_view_render (mathml_view, x / renderer->scale_x, y / renderer->scale_y);
+	lsm_dom_view_set_cairo (LSM_DOM_VIEW (mathml_view), cairo);
+	lsm_dom_view_render (LSM_DOM_VIEW (mathml_view), x / renderer->scale_x, y / renderer->scale_y);
 
 	cairo_restore (cairo);
 }
@@ -1426,13 +1378,13 @@ gog_renderer_draw_equation (GogRenderer *renderer, GMathmlView *mathml_view, dou
 GogRenderer*
 gog_renderer_new (GogGraph *graph)
 {
-	return g_object_new (GOG_RENDERER_TYPE, "model", graph, NULL);
+	return g_object_new (GOG_TYPE_RENDERER, "model", graph, NULL);
 }
 
 static void
 _cb_font_removed (GogRenderer *rend, GOFont const *font)
 {
-	g_return_if_fail (IS_GOG_RENDERER (rend));
+	g_return_if_fail (GOG_IS_RENDERER (rend));
 
 	gog_debug (0, g_warning ("notify a '%s' that %p is invalid",
 				 G_OBJECT_TYPE_NAME (rend), font););
@@ -1448,7 +1400,6 @@ gog_renderer_init (GogRenderer *rend)
 	rend->is_vector = FALSE;
 
 	rend->line_dash = NULL;
-	rend->outline_dash = NULL;
 
 	rend->needs_update = FALSE;
 	rend->cur_style    = NULL;
@@ -1482,8 +1433,6 @@ gog_renderer_finalize (GObject *obj)
 
 	go_line_dash_sequence_free (rend->line_dash);
 	rend->line_dash = NULL;
-	go_line_dash_sequence_free (rend->outline_dash);
-	rend->outline_dash = NULL;
 
 	if (rend->grip_style != NULL) {
 		g_object_unref (rend->grip_style);
@@ -1574,13 +1523,13 @@ gog_renderer_class_init (GogRendererClass *renderer_klass)
 		g_param_spec_object ("model",
 			_("Model"),
 			_("The GogGraph this renderer displays"),
-			GOG_GRAPH_TYPE,
+			GOG_TYPE_GRAPH,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, RENDERER_PROP_VIEW,
 		g_param_spec_object ("view",
 			_("View"),
 			_("the GogView this renderer is displaying"),
-			GOG_VIEW_TYPE,
+			GOG_TYPE_VIEW,
 			GSF_PARAM_STATIC | G_PARAM_READABLE));
 
 	renderer_signals [RENDERER_SIGNAL_REQUEST_UPDATE] = g_signal_new ("request-update",
