@@ -204,31 +204,37 @@ gog_theme_find_element (GogTheme const *theme, GogObject const *obj)
  * @style: #GOStyle to initialize
  * @obj: #GogObject The object associated with @style
  * @ind: an optional index
- * @complete_overwrite: boolean
+ * @relevant_fields: GOStyleFlag
  *
  * Fill in the auto aspects of @style based on @theme 's element for objects of
- * type/role similar to @obj with index @ind.  If @complete_overwrite is used,
- * fillin the entire style, not just the auto portions.
+ * type/role similar to @obj with index @ind.  If @relevant_fields is GO_STYLE_ALL,
+ * fillin the entire style, not just the auto portions included in @relevant_fields.
  **/
 void
 gog_theme_fillin_style (GogTheme const *theme, 
 			GOStyle *style,
 			GogObject const *obj, 
 			int ind, 
-			gboolean complete_overwrite)
+			GOStyleFlag relevant_fields)
 {
 	GogThemeElement *elem = gog_theme_find_element (theme, obj);
 
 	g_return_if_fail (elem != NULL);
 
-	if (complete_overwrite)
+	if (relevant_fields == GO_STYLE_ALL)
 		go_style_assign (style, elem->style);
 	else
-		go_style_apply_theme (style, elem->style);
+		go_style_apply_theme (style, elem->style, relevant_fields);
 
 /* FIXME FIXME FIXME we should handle the applicability here not in the map */
-	if (ind >= 0 && elem->map)
+	/* ensure only relevant fields are changed */
+	if (ind >= 0 && elem->map) {
+		/* ensure only relevant fields are changed */
+		GOStyleFlag flags = style->disable_theming;
+		style->disable_theming = GO_STYLE_ALL ^ relevant_fields;
 		(elem->map) (style, ind);
+		style->disable_theming = flags;
+	}
 }
 
 GogTheme *
@@ -496,73 +502,73 @@ _gog_themes_init (void)
 
 	/* graph */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0;
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0;
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogGraph", NULL);
 
 	/* chart */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogChart", NULL);
 
 	/* Legend */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogLegend", NULL);
 
 	/* Axis */
 	style = go_style_new ();
 	style->line.width = 0; /* hairline */
-	style->line.color = RGBA_BLACK;
+	style->line.color = GO_COLOR_BLACK;
 	gog_theme_add_element (theme, style, NULL, "GogAxis", NULL);
 
 	/* AxisLine */
 	style = go_style_new ();
 	style->line.width = 0; /* hairline */
-	style->line.color = RGBA_BLACK;
+	style->line.color = GO_COLOR_BLACK;
 	gog_theme_add_element (theme, style, NULL, "GogAxisLine", NULL);
 
 	/* Grid */
 	style = go_style_new ();
 	style->fill.type  = GO_STYLE_FILL_PATTERN;
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 1.;
-	style->outline.color = 0X848284ff;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_GREY (0xd0));
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 1.;
+	style->line.color = 0X848284ff;
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_GREY (0xd0));
 	gog_theme_add_element (theme, style, NULL, "GogGrid", NULL);
 
 	/* GridLine */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
+	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.4; 
-	style->line.color = RGBA_BLACK;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0xE0, 0xE0, 0xE0, 0xE0));
+	style->line.color = GO_COLOR_BLACK;
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0xE0, 0xE0, 0xE0, 0xE0));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style, NULL, NULL, "MajorGrid");
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
+	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.2; 
-	style->line.color = RGBA_BLACK; 
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0xE0, 0xE0, 0xE0, 0xE0));
+	style->line.color = GO_COLOR_BLACK; 
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0xE0, 0xE0, 0xE0, 0xE0));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style, NULL, NULL, "MinorGrid");
 	
 	/* Series */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
 	/* FIXME : not really true, will want to split area from line */
 	gog_theme_add_element (theme, style,
@@ -570,21 +576,21 @@ _gog_themes_init (void)
 
 	/* Chart titles */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0.;
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0.;
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	go_style_set_font_desc (style, pango_font_description_from_string ("Sans Bold 12"));
 	gog_theme_add_element (theme, style, NULL, "GogChart", "Title");
 
 	/* labels */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0.;
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0.;
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	go_style_set_font_desc (style, pango_font_description_from_string ("Sans 10"));
 	gog_theme_add_element (theme, style, NULL, "GogLabel", NULL);
 
@@ -592,30 +598,30 @@ _gog_themes_init (void)
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 1;
-	style->line.color = RGBA_BLACK;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0x00, 0x00, 0x00, 0x20));
+	style->line.color = GO_COLOR_BLACK;
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0x00, 0x00, 0x00, 0x20));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style,
 		NULL, "GogTrendLine", NULL);
 
 	/* regression equations */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style,
 		NULL, "GogRegEqn", NULL);
 
 #ifdef GOFFICE_WITH_LASEM
 	/* Equations */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	go_style_set_font_desc (style, pango_font_description_from_string ("Sans 10"));
 	gog_theme_add_element (theme, style,
 		NULL, "GogEquation", NULL);
@@ -632,120 +638,120 @@ _gog_themes_init (void)
 
 	/* graph */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0; 
-	style->outline.color = RGBA_BLACK; 
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0; 
+	style->line.color = GO_COLOR_BLACK; 
 	style->fill.type = GO_STYLE_FILL_GRADIENT;
 	style->fill.gradient.dir   = GO_GRADIENT_N_TO_S;
-	style->fill.pattern.fore = RGBA_BLUE;
-	style->fill.pattern.back = RGBA_BLACK;
+	style->fill.pattern.fore = GO_COLOR_BLUE;
+	style->fill.pattern.back = GO_COLOR_BLACK;
 	gog_theme_add_element (theme, style, NULL, "GogGraph", NULL);
 
 	/* chart */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogChart", NULL);
 
 	/* legend */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogLegend", NULL);
 
 	/* Axis */
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.; /* hairline */
-	style->line.color = RGBA_GREY (0x20);
+	style->line.color = GO_COLOR_GREY (0x20);
 	gog_theme_add_element (theme, style, NULL, "GogAxis", NULL);
 	
 	/* AxisLine */
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.; /* hairline */
-	style->line.color = RGBA_GREY (0x20);
+	style->line.color = GO_COLOR_GREY (0x20);
 	gog_theme_add_element (theme, style, NULL, "GogAxisLine", NULL);
 
 	/* Grid */
 	style = go_style_new ();
 	style->fill.type  = GO_STYLE_FILL_PATTERN;
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.color = RGBA_BLACK;
-	style->outline.width = 0;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_GREY (0xd0));
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.color = GO_COLOR_BLACK;
+	style->line.width = 0;
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_GREY (0xd0));
 	gog_theme_add_element (theme, style, NULL, "GogGrid", NULL);
 
 	/* GridLine */
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.; /* hairline */
-	style->line.color = RGBA_GREY (0x96);
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0xE0, 0xE0, 0xE0, 0xE0));
+	style->line.color = GO_COLOR_GREY (0x96);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0xE0, 0xE0, 0xE0, 0xE0));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style, NULL, NULL, "MajorGrid");
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 0.; /* hairline */
-	style->line.color = RGBA_GREY (0xC0);
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0xE0, 0xE0, 0xE0, 0xE0));
+	style->line.color = GO_COLOR_GREY (0xC0);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0xE0, 0xE0, 0xE0, 0xE0));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style, NULL, NULL, "MinorGrid");
 	
 	/* series */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0.; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0.; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_GREY (0x20));
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_GREY (0x20));
 	/* FIXME : not really true, will want to split area from line */
 	gog_theme_add_element (theme, style,
 		map_area_series_solid_guppi, "GogSeries", NULL);
 
 	/* labels */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0; /* none */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0; /* none */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style, NULL, "GogLabel", NULL);
 
 	/* trend lines */
 	style = go_style_new ();
 	style->line.dash_type = GO_LINE_SOLID;
 	style->line.width = 1;
-	style->line.color = RGBA_BLACK;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_TO_UINT (0x00, 0x00, 0x00, 0x20));
+	style->line.color = GO_COLOR_BLACK;
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_FROM_RGBA (0x00, 0x00, 0x00, 0x20));
 	style->fill.type = GO_STYLE_FILL_NONE;
 	gog_theme_add_element (theme, style,
 		NULL, "GogTrendLine", NULL);
 
 	/* regression equations */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_SOLID;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	gog_theme_add_element (theme, style,
 		NULL, "GogRegEqn", NULL);
 
 #ifdef GOFFICE_WITH_LASEM
 	/* Equations */
 	style = go_style_new ();
-	style->outline.dash_type = GO_LINE_NONE;
-	style->outline.width = 0; /* hairline */
-	style->outline.color = RGBA_BLACK;
+	style->line.dash_type = GO_LINE_NONE;
+	style->line.width = 0; /* hairline */
+	style->line.color = GO_COLOR_BLACK;
 	style->fill.type = GO_STYLE_FILL_NONE;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
 	go_style_set_font_desc (style, pango_font_description_from_string ("Sans 10"));
 	gog_theme_add_element (theme, style,
 		NULL, "GogEquation", NULL);
