@@ -19,9 +19,8 @@
  * USA
  */
 
-#include "go-gradient-selector.h"
-
-#include <goffice/utils/go-color.h>
+#include <goffice/goffice-config.h>
+#include <goffice/goffice.h>
 
 typedef struct {
 	GOColor start_color;
@@ -94,8 +93,8 @@ go_gradient_selector_new (GOGradientDirection initial_direction,
 	GOGradientSelectorState *state;
 
 	state = g_new (GOGradientSelectorState, 1);
-	state->start_color = RGBA_BLACK;
-	state->stop_color = RGBA_WHITE;
+	state->start_color = GO_COLOR_BLACK;
+	state->stop_color = GO_COLOR_WHITE;
 
 	palette = go_palette_new (GO_GRADIENT_MAX, 1.0, 4, 
 				  go_gradient_swatch_render_func, NULL,
