@@ -159,7 +159,7 @@ go_style_set_image_preview (GOImage *pix, StylePrefState *state)
 static void
 cb_outline_dash_type_changed (GOSelector *selector, StylePrefState const *state)
 {
-	GOStyleLine *line = &state->style->outline;
+	GOStyleLine *line = &state->style->line;
 
 	line->dash_type = go_selector_get_active (selector, &line->auto_dash);
 	set_style (state);
@@ -172,7 +172,7 @@ cb_outline_size_changed (GtkAdjustment *adj, StylePrefState *state)
 
 	g_return_if_fail (style != NULL);
 
-	style->outline.width = go_rint (adj->value * 100.) / 100.;
+	style->line.width = go_rint (adj->value * 100.) / 100.;
 	set_style (state);
 }
 
@@ -184,8 +184,8 @@ cb_outline_color_changed (GOSelector *selector,
 
 	g_return_if_fail (style != NULL);
 
-	style->outline.color = go_color_selector_get_color (selector, 
-							    &style->outline.auto_color);
+	style->line.color = go_color_selector_get_color (selector, 
+							    &style->line.auto_color);
 	set_style (state);
 }
 
@@ -207,20 +207,20 @@ outline_init (StylePrefState *state, gboolean enable, GOEditor *editor)
 	table = go_gtk_builder_get_widget (state->gui, "outline_table");
 
 	/* DashType */
-	w = go_line_dash_selector_new (style->outline.dash_type,
-				       default_style->outline.dash_type);
+	w = go_line_dash_selector_new (style->line.dash_type,
+				       default_style->line.dash_type);
 	gtk_table_attach (GTK_TABLE (table), w, 1, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	g_signal_connect (G_OBJECT (w), "activate", 
 			  G_CALLBACK (cb_outline_dash_type_changed), state);
 	/* Size */
 	w = go_gtk_builder_get_widget (state->gui, "outline_size_spin");
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), style->outline.width);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), style->line.width);
 	g_signal_connect (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w)),
 		"value_changed",
 		G_CALLBACK (cb_outline_size_changed), state);
 	/* Color */
 	w = create_go_combo_color (state,
-		style->outline.color, default_style->outline.color,
+		style->line.color, default_style->line.color,
 		state->gui,
 		"outline_color", "outline_color_label",
 		G_CALLBACK (cb_outline_color_changed));
@@ -749,7 +749,7 @@ marker_init (StylePrefState *state, gboolean enable, GOEditor *editor, GOCmdCont
 					       go_marker_get_fill_color (style->marker.mark));
 	else
 		go_marker_selector_set_colors (GO_SELECTOR (selector), 
-					       RGBA_BLUE, RGBA_BLUE);
+					       GO_COLOR_BLUE, GO_COLOR_BLUE);
 	w = go_gtk_builder_get_widget (gui, "marker_shape_label");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (w), selector);
 	gtk_table_attach (GTK_TABLE (table), selector, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -765,7 +765,7 @@ marker_init (StylePrefState *state, gboolean enable, GOEditor *editor, GOCmdCont
 			G_CALLBACK (cb_marker_fill_color_changed));
 	else {
 		w = create_go_combo_color (state,
-			RGBA_BLUE, RGBA_BLUE,
+			GO_COLOR_BLUE, GO_COLOR_BLUE,
 			gui, "pattern_background", "marker_fill_label",
 			G_CALLBACK (cb_marker_fill_color_changed));
 		gtk_widget_set_sensitive (w, FALSE);
@@ -780,7 +780,7 @@ marker_init (StylePrefState *state, gboolean enable, GOEditor *editor, GOCmdCont
 			G_CALLBACK (cb_marker_outline_color_changed));
 	else {
 		w = create_go_combo_color (state,
-			RGBA_BLUE, RGBA_BLUE,
+			GO_COLOR_BLUE, GO_COLOR_BLUE,
 			gui, "pattern_background", "marker_fill_label",
 			G_CALLBACK (cb_marker_outline_color_changed));
 		gtk_widget_set_sensitive (w, FALSE);
@@ -1066,7 +1066,6 @@ go_style_assign (GOStyle *dst, GOStyle const *src)
 	if (dst->font.font != NULL)
 		go_font_unref (dst->font.font);
 
-	dst->outline = src->outline;
 	dst->fill    = src->fill;
 	dst->line    = src->line;
 	if (dst->marker.mark)
@@ -1093,7 +1092,7 @@ go_style_assign (GOStyle *dst, GOStyle const *src)
  * assigned (is_auto)
  **/
 void
-go_style_apply_theme (GOStyle *dst, GOStyle const *src)
+go_style_apply_theme (GOStyle *dst, GOStyle const *src, GOStyleFlag fields)
 {
 	if (src == dst)
 		return;
@@ -1101,30 +1100,34 @@ go_style_apply_theme (GOStyle *dst, GOStyle const *src)
 	g_return_if_fail (GO_IS_STYLE (src));
 	g_return_if_fail (GO_IS_STYLE (dst));
 
-	if (dst->outline.auto_dash)
-		dst->outline.dash_type = src->outline.dash_type;
-	if (dst->outline.auto_color)
-		dst->outline.color = src->outline.color;
-	if (dst->fill.auto_type)
-		dst->fill.type = src->fill.type;
-	if (dst->fill.auto_fore)
-		dst->fill.pattern.fore = src->fill.pattern.fore;
-	if (dst->fill.auto_back)
-		dst->fill.pattern.back = src->fill.pattern.back;
-	if (dst->line.auto_dash)
-		dst->line.dash_type = src->line.dash_type;
-	if (dst->line.auto_color)
-		dst->line.color = src->line.color;
-	if (dst->marker.auto_shape)
-		go_marker_set_shape (dst->marker.mark,
-			go_marker_get_shape (src->marker.mark));
-	if (dst->marker.auto_outline_color)
-		go_marker_set_outline_color (dst->marker.mark,
-			go_marker_get_outline_color (src->marker.mark));
-	if (dst->marker.auto_fill_color)
-		go_marker_set_fill_color (dst->marker.mark,
-			go_marker_get_fill_color (src->marker.mark));
-	if (dst->text_layout.auto_angle)
+	if (fields & GO_STYLE_FILL) {
+		if (dst->fill.auto_type)
+			dst->fill.type = src->fill.type;
+		if (dst->fill.auto_fore)
+			dst->fill.pattern.fore = src->fill.pattern.fore;
+		if (dst->fill.auto_back)
+			dst->fill.pattern.back = src->fill.pattern.back;
+	}
+
+	if (fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE)) {
+		if (dst->line.auto_dash)
+			dst->line.dash_type = src->line.dash_type;
+		if (dst->line.auto_color)
+			dst->line.color = src->line.color;
+	}
+	if (fields & GO_STYLE_MARKER) {
+		if (dst->marker.auto_shape)
+			go_marker_set_shape (dst->marker.mark,
+				go_marker_get_shape (src->marker.mark));
+		if (dst->marker.auto_outline_color)
+			go_marker_set_outline_color (dst->marker.mark,
+				go_marker_get_outline_color (src->marker.mark));
+		if (dst->marker.auto_fill_color)
+			go_marker_set_fill_color (dst->marker.mark,
+			                          go_marker_get_fill_color (src->marker.mark));
+	}
+
+	if ((fields & GO_STYLE_TEXT_LAYOUT) && dst->text_layout.auto_angle)
 		dst->text_layout.angle = src->text_layout.angle;
 
 #if 0
@@ -1181,9 +1184,9 @@ go_style_init (GOStyle *style)
 	style->line.miter_limit = 10.;
 	style->fill.type = GO_STYLE_FILL_NONE;
 	style->fill.gradient.brightness = -1.;
-	go_pattern_set_solid (&style->fill.pattern, RGBA_BLACK);
+	go_pattern_set_solid (&style->fill.pattern, GO_COLOR_BLACK);
 	style->font.font = go_font_new_by_index (0);
-	style->font.color = RGBA_BLACK;
+	style->font.color = GO_COLOR_BLACK;
 	style->text_layout.angle = 0.0;
 }
 
@@ -1621,7 +1624,7 @@ go_style_persist_dom_load (GOPersist *gp, xmlNode *node)
 		if (xmlIsBlankNode (ptr) || ptr->name == NULL)
 			continue;
 		if (strcmp (ptr->name, "outline") == 0)
-			go_style_line_load (ptr, &style->outline);
+			go_style_line_load (ptr, &style->line);
 		else if (strcmp (ptr->name, "line") == 0)
 			go_style_line_load (ptr, &style->line);
 		else if (strcmp (ptr->name, "fill") == 0)
@@ -1640,7 +1643,7 @@ static void
 go_style_sax_load_line (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	GOStyle *style = GO_STYLE (xin->user_state);
-	GOStyleLine *line = xin->node->user_data.v_int ? &style->outline : &style->line;
+	GOStyleLine *line = &style->line;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
 		if (0 == strcmp (attrs[0], "dash"))
@@ -1784,7 +1787,7 @@ go_style_persist_sax_save (GOPersist const *gp, GsfXMLOut *output)
 		G_OBJECT_TYPE_NAME (style));
 
 	if (style->interesting_fields & GO_STYLE_OUTLINE)
-		go_style_line_sax_save (output, "outline", &style->outline);
+		go_style_line_sax_save (output, "outline", &style->line);
 	if (style->interesting_fields & GO_STYLE_LINE)
 		go_style_line_sax_save (output, "line", &style->line);
 	if (style->interesting_fields & GO_STYLE_FILL)
@@ -1867,8 +1870,7 @@ go_style_is_different_size (GOStyle const *a, GOStyle const *b)
 {
 	if (a == NULL || b == NULL)
 		return TRUE;
-	return	a->outline.dash_type != b->outline.dash_type ||
-		a->outline.width != b->outline.width ||
+	return	a->line.dash_type != b->line.dash_type ||
 		a->line.width != b->line.width ||
 		a->fill.type != b->fill.type ||
 		a->text_layout.angle != b->text_layout.angle ||
@@ -1891,8 +1893,8 @@ go_style_is_outline_visible (GOStyle const *style)
 	g_return_val_if_fail (GO_IS_STYLE (style), FALSE);
 
 	/* FIXME FIXME FIXME make this smarter */
-	return UINT_RGBA_A (style->outline.color) > 0 && 
-		style->outline.dash_type != GO_LINE_NONE;
+	return GO_COLOR_UINT_A (style->line.color) > 0 && 
+		style->line.dash_type != GO_LINE_NONE;
 }
 
 gboolean
@@ -1901,7 +1903,7 @@ go_style_is_line_visible (GOStyle const *style)
 	g_return_val_if_fail (GO_IS_STYLE (style), FALSE);
 
 	/* FIXME FIXME FIXME TODO : make this smarter */
-	return UINT_RGBA_A (style->line.color) > 0 && 
+	return GO_COLOR_UINT_A (style->line.color) > 0 && 
 		style->line.dash_type != GO_LINE_NONE;
 }
 
@@ -1924,8 +1926,6 @@ go_style_force_auto (GOStyle *style)
 	style->marker.auto_shape =
 	style->marker.auto_outline_color =
 	style->marker.auto_fill_color =
-	style->outline.auto_dash =
-	style->outline.auto_color =
 	style->line.auto_dash =
 	style->line.auto_color =
 	style->fill.auto_type =
@@ -2006,8 +2006,8 @@ go_style_set_fill_brightness (GOStyle *style, float brightness)
 
 	style->fill.gradient.brightness = brightness;
 	style->fill.pattern.fore = (brightness < 50.)
-		? UINT_INTERPOLATE(style->fill.pattern.back, RGBA_WHITE, 1. - brightness / 50.)
-		: UINT_INTERPOLATE(style->fill.pattern.back, RGBA_BLACK, brightness / 50. - 1.);
+		? GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_WHITE, 1. - brightness / 50.)
+		: GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_BLACK, brightness / 50. - 1.);
 }
 
 /**
