@@ -55,10 +55,8 @@ static GogObjectClass *plot1_5d_parent_klass;
 static void
 gog_plot_1_5d_clear_formats (GogPlot1_5d *plot)
 {
-	if (plot->fmt != NULL) {
-		go_format_unref (plot->fmt);
-		plot->fmt = NULL;
-	}
+	go_format_unref (plot->fmt);
+	plot->fmt = NULL;
 }
 
 static void
@@ -578,6 +576,7 @@ gog_series1_5d_populate_editor (GogObject *obj,
 		g_object_get (G_OBJECT (series->plot), "horizontal", &horizontal, NULL);
 	error_page = gog_error_bar_prefs (series, "errors", horizontal, dalloc, cc);
 	go_editor_add_page (editor, error_page, _("Error bars"));
+	g_object_unref (error_page);
 }
 #endif
 
