@@ -474,7 +474,6 @@ gog_box_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (model->outliers) {
 			double l1, l2, m1, m2, d, r = 2. * hrect * model->radius_ratio;
 			int i = 0;
-			style->outline = style->line;
 			d = series->vals[3] - series->vals[1];
 			l1 = series->vals[1] - d * 1.5;
 			l2 = series->vals[1] - d * 3.;
@@ -625,14 +624,6 @@ gog_box_plot_series_update (GogObject *obj)
 		gog_box_plot_series_parent_klass->update (obj);
 }
 
-static void
-gog_box_plot_series_init_style (GogStyledObject *gso, GOStyle *style)
-{
-	((GogStyledObjectClass*) gog_box_plot_series_parent_klass)->init_style (gso, style);
-
-	style->outline.dash_type = GO_LINE_NONE;
-}
-
 static void
 gog_box_plot_series_finalize (GObject *obj)
 {
@@ -644,12 +635,10 @@ static void
 gog_box_plot_series_class_init (GogObjectClass *obj_klass)
 {
 	GObjectClass *object_class = (GObjectClass *) obj_klass;
-	GogStyledObjectClass *gso_klass = (GogStyledObjectClass*) obj_klass;
 
 	gog_box_plot_series_parent_klass = g_type_class_peek_parent (obj_klass);
 	object_class->finalize = gog_box_plot_series_finalize;
 	obj_klass->update = gog_box_plot_series_update;
-	gso_klass->init_style = gog_box_plot_series_init_style;
 }
 
 GSF_DYNAMIC_CLASS (GogBoxPlotSeries, gog_box_plot_series,
