@@ -30,12 +30,13 @@
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-format.h>
 #include <goffice/utils/go-path.h>
+#include <goffice/utils/go-styled-object.h>
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
-#define GOG_HISTOGRAM_PLOT_SERIES_TYPE	(gog_histogram_plot_series_get_type ())
-#define GOG_HISTOGRAM_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_HISTOGRAM_PLOT_SERIES_TYPE, GogHistogramPlotSeries))
-#define IS_GOG_HISTOGRAM_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_HISTOGRAM_PLOT_SERIES_TYPE))
+#define GOG_TYPE_HISTOGRAM_PLOT_SERIES	(gog_histogram_plot_series_get_type ())
+#define GOG_HISTOGRAM_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_HISTOGRAM_PLOT_SERIES, GogHistogramPlotSeries))
+#define GOG_IS_HISTOGRAM_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_HISTOGRAM_PLOT_SERIES))
 
 typedef struct {
 	GogSeries base;
@@ -52,14 +53,11 @@ static GogObjectClass *histogram_plot_parent_klass;
 static void
 gog_histogram_plot_clear_formats (GogHistogramPlot *model)
 {
-	if (model->x.fmt != NULL) {
-		go_format_unref (model->x.fmt);
-		model->x.fmt = NULL;
-	}
-	if (model->y.fmt != NULL) {
-		go_format_unref (model->y.fmt);
-		model->y.fmt = NULL;
-	}
+	go_format_unref (model->x.fmt);
+	model->x.fmt = NULL;
+
+	go_format_unref (model->y.fmt);
+	model->y.fmt = NULL;
 }
 
 static char const *
@@ -86,11 +84,12 @@ gog_histogram_plot_update (GogObject *obj)
 	g_free (series->x);
 	series->x = g_new (double, series->base.num_elements);
 	if (series->base.values[0].data != NULL) {
-		x_vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[0].data));
+		x_vals = go_data_get_values (series->base.values[0].data);
 		x_min = x_vals[0];
 		x_max = x_vals[series->base.num_elements];
 		if (model->x.fmt == NULL)
 			model->x.fmt = go_data_preferred_fmt (series->base.values[0].data);
+		model->x.date_conv = go_data_date_conv (series->base.values[0].data);
 		for (i = 0; i < series->base.num_elements; i++)
 			series->x[i] = (x_vals[i] + x_vals[i+1]) / 2;
 	} else {
@@ -110,7 +109,7 @@ gog_histogram_plot_update (GogObject *obj)
 	if (series->base.values[1].data != NULL) {
 		if (x_vals) {
 			series->y = g_new (double, series->base.num_elements);
-			y_vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
+			y_vals = go_data_get_values (series->base.values[1].data);
 			for (i = 0; i < series->base.num_elements; i++)
 				if (go_finite (y_vals[i])) {
 					series->y[i] = val = y_vals[i] / (x_vals[i+1] - x_vals[i]);
@@ -121,10 +120,10 @@ gog_histogram_plot_update (GogObject *obj)
 				} else
 					series->y[i] = 0.;
 		} else
-			go_data_vector_get_minmax (
-				GO_DATA_VECTOR (series->base.values[1].data), &y_min, &y_max);
+			go_data_get_bounds (series->base.values[1].data, &y_min, &y_max);
 		if (model->y.fmt == NULL)
 			model->y.fmt = go_data_preferred_fmt (series->base.values[1].data);
+		model->y.date_conv = go_data_date_conv (series->base.values[1].data);
 	}
 	if (y_min > y_max)
 		y_min = y_max = go_nan;
@@ -148,11 +147,15 @@ gog_histogram_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 		bounds->val.maxima = model->x.maxima;
 		if (bounds->fmt == NULL && model->x.fmt != NULL)
 			bounds->fmt = go_format_ref (model->x.fmt);
+		if (model->x.date_conv)
+			bounds->date_conv = model->x.date_conv;
 	} else {
 		bounds->val.minima = model->y.minima;
 		bounds->val.maxima = model->y.maxima;
 		if (bounds->fmt == NULL && model->y.fmt != NULL)
 			bounds->fmt = go_format_ref (model->y.fmt);
+		if (model->y.date_conv)
+			bounds->date_conv = model->y.date_conv;
 	}
 	bounds->is_discrete = FALSE;
 	return NULL;
@@ -193,7 +196,7 @@ gog_histogram_plot_class_init (GogPlotClass *gog_plot_klass)
 	plot_klass->desc.num_series_max = 1;
 	plot_klass->series_type = gog_histogram_plot_series_get_type ();
 	plot_klass->axis_set = GOG_AXIS_SET_XY;
-	plot_klass->desc.series.style_fields	= GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields	= GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	plot_klass->axis_get_bounds   		= gog_histogram_plot_axis_get_bounds;
 }
 
@@ -207,7 +210,7 @@ gog_histogram_plot_init (GogHistogramPlot *hist)
 
 GSF_DYNAMIC_CLASS (GogHistogramPlot, gog_histogram_plot,
 	gog_histogram_plot_class_init, gog_histogram_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 /*****************************************************************************/
 typedef GogPlotView		GogHistogramPlotView;
@@ -226,7 +229,7 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	unsigned i, j, nb;
 	GOPath *path ;
 	GSList *ptr;
-	GogStyle *style;
+	GOStyle *style;
 
 	if (model->base.series == NULL)
 		return;
@@ -249,10 +252,8 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	y_map = gog_chart_map_get_axis_map (chart_map, 1);
 
 	if (series->base.values[0].data)
-		x_vals = go_data_vector_get_values (
-			GO_DATA_VECTOR (series->base.values[0].data));
-	y_vals = (x_vals)? series->y: go_data_vector_get_values (
-		GO_DATA_VECTOR (series->base.values[1].data));
+		x_vals = go_data_get_values (series->base.values[0].data);
+	y_vals = (x_vals)? series->y: go_data_get_values (series->base.values[1].data);
 
 	path = go_path_new ();
 	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
@@ -272,7 +273,7 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 		GOPath *drop_path = go_path_new ();
 		go_path_set_options (drop_path, GO_PATH_OPTIONS_SHARP);
 		gog_renderer_push_style (view->renderer,
-			gog_styled_object_get_style (GOG_STYLED_OBJECT (series->droplines)));
+			go_styled_object_get_style (GO_STYLED_OBJECT (series->droplines)));
 		cury = y0;
 		for (i = 1; i < series->base.num_elements; i++) {
 			curx = gog_axis_map_to_view (x_map, ((x_vals)? x_vals[i]: 0.));
@@ -327,16 +328,16 @@ gog_histogram_plot_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogHistogramPlotView, gog_histogram_plot_view,
 	gog_histogram_plot_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
 typedef GogView		GogHistogramSeriesView;
 typedef GogViewClass	GogHistogramSeriesViewClass;
 
-#define GOG_HISTOGRAM_SERIES_VIEW_TYPE	(gog_histogram_series_view_get_type ())
-#define GOG_HISTOGRAM_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_HISTOGRAM_SERIES_VIEW_TYPE, GogHistogramSeriesView))
-#define IS_GOG_HISTOGRAM_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_HISTOGRAM_SERIES_VIEW_TYPE))
+#define GOG_TYPE_HISTOGRAM_SERIES_VIEW	(gog_histogram_series_view_get_type ())
+#define GOG_HISTOGRAM_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_HISTOGRAM_SERIES_VIEW, GogHistogramSeriesView))
+#define GOG_IS_HISTOGRAM_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_HISTOGRAM_SERIES_VIEW))
 
 static void
 gog_histogram_series_view_render (GogView *view, GogViewAllocation const *bbox)
@@ -366,7 +367,7 @@ gog_histogram_series_view_class_init (GogHistogramSeriesViewClass *gview_klass)
 
 GSF_DYNAMIC_CLASS (GogHistogramSeriesView, gog_histogram_series_view,
 	gog_histogram_series_view_class_init, NULL,
-	GOG_VIEW_TYPE)
+	GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 
@@ -408,14 +409,12 @@ gog_histogram_plot_series_update (GogObject *obj)
 	GSList *ptr;
 
 	if (series->base.values[1].data != NULL) {
-		y_vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
-		y_len = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->base.values[1].data));
+		y_vals = go_data_get_values (series->base.values[1].data);
+		y_len = go_data_get_vector_size (series->base.values[1].data);
 	}
 	if (series->base.values[0].data != NULL) {
-		x_vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[0].data));
-		max = go_data_vector_get_len 
-			(GO_DATA_VECTOR (series->base.values[0].data));
+		x_vals = go_data_get_values (series->base.values[0].data);
+		max = go_data_get_vector_size (series->base.values[0].data);
 		if (max > 0 && go_finite (x_vals[0])) {
 			cur = x_vals[0];
 			for (i = 1; i< max; i++) {
@@ -432,7 +431,7 @@ gog_histogram_plot_series_update (GogObject *obj)
 
 	/* update children */
 	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
-		if (!IS_GOG_SERIES_LINES (ptr->data))
+		if (!GOG_IS_SERIES_LINES (ptr->data))
 			gog_object_request_update (GOG_OBJECT (ptr->data));
 
 	/* queue plot for redraw */
@@ -462,9 +461,10 @@ gog_histogram_plot_series_get_xy_data (GogSeries const *series,
 					double const **x, double const **y)
 {
 	GogHistogramPlotSeries *hist_ser = GOG_HISTOGRAM_PLOT_SERIES (series);
+
 	*x = hist_ser->x;
-	*y = (hist_ser->y)? hist_ser->y:
-		go_data_vector_get_values (GO_DATA_VECTOR (series->values[1].data));
+	*y = (hist_ser->y)? hist_ser->y: go_data_get_values (series->values[1].data);
+
 	return series->num_elements;
 }
 
@@ -482,9 +482,8 @@ gog_histogram_plot_series_class_init (GogObjectClass *obj_klass)
 			NULL },
 	};
 	GogSeriesClass *series_klass = (GogSeriesClass*) obj_klass;
-	GogStyledObjectClass *gso_klass = (GogStyledObjectClass*) obj_klass;
-	GogObjectClass *gog_klass = (GogObjectClass *)gso_klass;
-	GObjectClass *gobject_klass = (GObjectClass *) gso_klass;
+	GogObjectClass *gog_klass = (GogObjectClass *)obj_klass;
+	GObjectClass *gobject_klass = (GObjectClass *) obj_klass;
 
 	series_parent_klass = g_type_class_peek_parent (obj_klass);
 	gobject_klass->finalize		= gog_histogram_plot_series_finalize;
@@ -508,4 +507,4 @@ gog_histogram_plot_series_init (GObject *obj)
 
 GSF_DYNAMIC_CLASS (GogHistogramPlotSeries, gog_histogram_plot_series,
 	gog_histogram_plot_series_class_init, gog_histogram_plot_series_init,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
