@@ -73,14 +73,11 @@ static void gog_2d_plot_adjust_bounds (Gog2DPlot *model, double *x_min, double *
 static void
 gog_2d_plot_clear_formats (Gog2DPlot *plot2d)
 {
-	if (plot2d->x.fmt != NULL) {
-		go_format_unref (plot2d->x.fmt);
-		plot2d->x.fmt = NULL;
-	}
-	if (plot2d->y.fmt != NULL) {
-		go_format_unref (plot2d->y.fmt);
-		plot2d->y.fmt = NULL;
-	}
+	go_format_unref (plot2d->x.fmt);
+	plot2d->x.fmt = NULL;
+
+	go_format_unref (plot2d->y.fmt);
+	plot2d->y.fmt = NULL;
 }
 
 static void
@@ -426,9 +423,9 @@ gog_bubble_plot_populate_editor (GogObject *obj,
 				 G_GNUC_UNUSED GogDataAllocator *dalloc,
 			GOCmdContext *cc)
 {
-	go_editor_add_page (editor,
-			     gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc),
-			     _("Properties"));
+	GtkWidget *w = gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc);
+	go_editor_add_page (editor, w, _("Properties"));
+	g_object_unref (G_OBJECT (w));
 
 	(GOG_OBJECT_CLASS(bubble_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 }
@@ -604,10 +601,8 @@ static GogObjectClass *map_parent_klass;
 static void
 gog_xy_color_plot_clear_formats (GogXYColorPlot *map)
 {
-	if (map->z.fmt != NULL) {
-		go_format_unref (map->z.fmt);
-		map->z.fmt = NULL;
-	}
+	go_format_unref (map->z.fmt);
+	map->z.fmt = NULL;
 }
 
 static void
@@ -686,23 +681,23 @@ gog_xy_color_plot_populate_editor (GogObject *obj,
 				   GOCmdContext *cc)
 {
 #ifdef GOFFICE_WITH_GTK
-	GladeXML *gui;
+	GtkBuilder *gui;
 	char const *dir;
 	char *path;
 
 	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
-	path = g_build_filename (dir, "gog-xy-color-prefs.glade", NULL);
-	gui = go_glade_new (path, "gog-xy-color-prefs", GETTEXT_PACKAGE, cc);
+	path = g_build_filename (dir, "gog-xy-color-prefs.ui", NULL);
+	gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
 	g_free (path);
 
 	if (gui != NULL) {
-		GtkWidget *w = glade_xml_get_widget (gui, "hide-outliers");
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "hide-outliers");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				(GOG_XY_COLOR_PLOT (obj))->hide_outliers);
 		g_signal_connect (G_OBJECT (w),
 			"toggled",
 			G_CALLBACK (hide_outliers_toggled_cb), obj);
-		w = glade_xml_get_widget (gui, "gog-xy-color-prefs");
+		w = go_gtk_builder_get_widget (gui, "gog-xy-color-prefs");
 		go_editor_add_page (editor, w, _("Properties"));
 		g_object_unref (gui);
 	}
@@ -845,16 +840,16 @@ get_map_color (double z, gboolean hide_outliers)
 	if (hide_outliers && (z < 0. || z > 6.))
 		return 0;
 	if (z <= 0.)
-		return RGBA_BLUE;
+		return GO_COLOR_BLUE;
 	if (z <= 1.)
-		return RGBA_BLUE + ((int) (z * 255.) << 16);
+		return GO_COLOR_BLUE + ((int) (z * 255.) << 16);
 	if (z <= 2.)
-		return RGBA_GREEN + ((int) ((2. - z) * 255) << 8);
+		return GO_COLOR_GREEN + ((int) ((2. - z) * 255) << 8);
 	if (z <= 4.)
-		return RGBA_GREEN + ((int) ((z / 2. - 1.) * 255) << 24);
+		return GO_COLOR_GREEN + ((int) ((z / 2. - 1.) * 255) << 24);
 	if (z <= 6.)
-		return RGBA_RED + ((int) ((3. - z / 2.) * 255) << 16);
-	return RGBA_RED;
+		return GO_COLOR_RED + ((int) ((3. - z / 2.) * 255) << 16);
+	return GO_COLOR_RED;
 }
 
 typedef struct {
@@ -1123,7 +1118,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				neg_style = go_style_dup (GOG_STYLED_OBJECT (series)->style);
 				neg_style->fill.type = GO_STYLE_FILL_PATTERN;
 				neg_style->fill.pattern.pattern = GO_PATTERN_SOLID;
-				neg_style->fill.pattern.back = RGBA_WHITE;
+				neg_style->fill.pattern.back = GO_COLOR_WHITE;
 			}
 		}
 
@@ -1178,7 +1173,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 									GO_STYLED_OBJECT (gse)));
 					} else if (model->base.vary_style_by_element)
 						gog_theme_fillin_style (theme, style, GOG_OBJECT (series),
-									model->base.index_num + i - 1, FALSE);
+									model->base.index_num + i - 1, style->interesting_fields);
 					gog_renderer_draw_circle (view->renderer, x_canvas, y_canvas, 
 							    ((size_as_area) ?
 							    sqrt (z / zmax) :
@@ -1420,7 +1415,7 @@ gog_xy_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 	else
 		style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
+		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, style->interesting_fields);
 }
 
 static void
@@ -1743,15 +1738,15 @@ gog_xy_series_populate_editor (GogObject *obj,
 	GtkWidget *w;
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
-	char *path = g_build_filename (dir, "gog-xy-series-prefs.glade", NULL);
-	GladeXML *gui = go_glade_new (path, "gog_xy_series_prefs", GETTEXT_PACKAGE, cc);
+	char *path = g_build_filename (dir, "gog-xy-series-prefs.ui", NULL);
+	GtkBuilder *gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
 
 	g_free (path);
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 
 	if (gui != NULL) {
-		w = glade_xml_get_widget (gui, "invalid_as_zero");
+		w = go_gtk_builder_get_widget (gui, "invalid_as_zero");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				(GOG_XY_SERIES (obj))->invalid_as_zero);
 		g_signal_connect (G_OBJECT (w),
@@ -1759,17 +1754,18 @@ gog_xy_series_populate_editor (GogObject *obj,
 			G_CALLBACK (invalid_toggled_cb), obj);
 		series = GOG_XY_SERIES (obj);
 
-		w = glade_xml_get_widget (gui, "gog_xy_series_prefs");
-		g_object_set_data_full (G_OBJECT (w),
-			"state", gui, (GDestroyNotify)g_object_unref);
+		w = go_gtk_builder_get_widget (gui, "gog_xy_series_prefs");
 
 		go_editor_add_page (editor, w, _("Details"));
+		g_object_unref (gui);
 	}
 
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "x-errors", TRUE, dalloc, cc);
 	go_editor_add_page (editor, w, _("X error bars"));
+	g_object_unref (w);
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "y-errors", FALSE, dalloc, cc);
 	go_editor_add_page (editor, w, _("Y error bars"));
+	g_object_unref (w);
 }
 #endif
 
